@@ -11,8 +11,8 @@
 #include <QPointer>
 #include <QVariantHash>
 
-namespace Bugzilla {
-
+namespace Bugzilla
+{
 /// https://bugzilla.readthedocs.io/en/5.0/api/core/v1/field.html
 class BugFieldValue : public QObject
 {
@@ -63,7 +63,7 @@ public:
         SeeAlso = 7,
         Keywords = 8,
         Date = 9,
-        Integer = 10
+        Integer = 10,
     };
 
     typedef QPointer<BugField> Ptr;
