@@ -16,6 +16,7 @@
 #include <KMessageBox>
 
 #include "drkonqi.h"
+#include "drkonqi_debug.h"
 
 #include "backtracegenerator.h"
 #include "debuggermanager.h"
@@ -53,103 +54,107 @@ ReportAssistantDialog::ReportAssistantDialog(QWidget *parent)
     const bool skipIntroduction = group.readEntry("SkipIntroduction", false);
 
     if (!skipIntroduction) {
-        IntroductionPage *m_introduction = new IntroductionPage(this);
+        auto *m_introduction = new IntroductionPage(this);
 
-        KPageWidgetItem *m_introductionPage = new KPageWidgetItem(m_introduction, QLatin1String(PAGE_INTRODUCTION_ID));
+        auto *m_introductionPage = new KPageWidgetItem(m_introduction, QLatin1String(PAGE_INTRODUCTION_ID));
         m_pageWidgetMap.insert(QLatin1String(PAGE_INTRODUCTION_ID), m_introductionPage);
         m_introductionPage->setHeader(i18nc("@title", "Welcome to the Reporting Assistant"));
         m_introductionPage->setIcon(QIcon::fromTheme(QStringLiteral("tools-report-bug")));
-
-        addPage(m_introductionPage);
+        m_pageItems.push_back(m_introductionPage);
     }
 
     //-Bug Awareness Page
-    BugAwarenessPage *m_awareness = new BugAwarenessPage(this);
+    auto *m_awareness = new BugAwarenessPage(this);
     connectSignals(m_awareness);
 
-    KPageWidgetItem *m_awarenessPage = new KPageWidgetItem(m_awareness, QLatin1String(PAGE_AWARENESS_ID));
+    auto *m_awarenessPage = new KPageWidgetItem(m_awareness, QLatin1String(PAGE_AWARENESS_ID));
     m_pageWidgetMap.insert(QLatin1String(PAGE_AWARENESS_ID), m_awarenessPage);
     m_awarenessPage->setHeader(i18nc("@title", "What do you know about the crash?"));
     m_awarenessPage->setIcon(QIcon::fromTheme(QStringLiteral("checkbox")));
 
     //-Crash Information Page
-    CrashInformationPage *m_backtrace = new CrashInformationPage(this);
+    auto *m_backtrace = new CrashInformationPage(this);
     connectSignals(m_backtrace);
 
-    KPageWidgetItem *m_backtracePage = new KPageWidgetItem(m_backtrace, QLatin1String(PAGE_CRASHINFORMATION_ID));
+    auto *m_backtracePage = new KPageWidgetItem(m_backtrace, QLatin1String(PAGE_CRASHINFORMATION_ID));
     m_pageWidgetMap.insert(QLatin1String(PAGE_CRASHINFORMATION_ID), m_backtracePage);
     m_backtracePage->setHeader(i18nc("@title", "Fetching the Backtrace (Automatic Crash Information)"));
     m_backtracePage->setIcon(QIcon::fromTheme(QStringLiteral("run-build")));
 
     //-Results Page
-    ConclusionPage *m_conclusions = new ConclusionPage(this);
+    auto *m_conclusions = new ConclusionPage(this);
     connectSignals(m_conclusions);
 
-    KPageWidgetItem *m_conclusionsPage = new KPageWidgetItem(m_conclusions, QLatin1String(PAGE_CONCLUSIONS_ID));
+    auto *m_conclusionsPage = new KPageWidgetItem(m_conclusions, QLatin1String(PAGE_CONCLUSIONS_ID));
     m_pageWidgetMap.insert(QLatin1String(PAGE_CONCLUSIONS_ID), m_conclusionsPage);
     m_conclusionsPage->setHeader(i18nc("@title", "Results of the Analyzed Crash Details"));
     m_conclusionsPage->setIcon(QIcon::fromTheme(QStringLiteral("dialog-information")));
     connect(m_conclusions, &ConclusionPage::finished, this, &ReportAssistantDialog::assistantFinished);
 
     // Version check page
-    BugzillaVersionPage *versionPage = new BugzillaVersionPage(this);
+    auto *versionPage = new BugzillaVersionPage(this);
     m_pageWidgetMap.insert(QLatin1String(PAGE_BZVERSION_ID), versionPage->item());
 
     //-Bugzilla Login
-    BugzillaLoginPage *m_bugzillaLogin = new BugzillaLoginPage(this);
+    auto *m_bugzillaLogin = new BugzillaLoginPage(this);
     connectSignals(m_bugzillaLogin);
 
-    KPageWidgetItem *m_bugzillaLoginPage = new KPageWidgetItem(m_bugzillaLogin, QLatin1String(PAGE_BZLOGIN_ID));
+    auto *m_bugzillaLoginPage = new KPageWidgetItem(m_bugzillaLogin, QLatin1String(PAGE_BZLOGIN_ID));
     m_pageWidgetMap.insert(QLatin1String(PAGE_BZLOGIN_ID), m_bugzillaLoginPage);
     m_bugzillaLoginPage->setHeader(i18nc("@title", "Login into %1", i18n(KDE_BUGZILLA_DESCRIPTION)));
     m_bugzillaLoginPage->setIcon(QIcon::fromTheme(QStringLiteral("user-identity")));
     connect(m_bugzillaLogin, &BugzillaLoginPage::loggedTurnToNextPage, this, &ReportAssistantDialog::loginFinished);
 
     //-Bugzilla duplicates
-    BugzillaDuplicatesPage *m_bugzillaDuplicates = new BugzillaDuplicatesPage(this);
+    auto *m_bugzillaDuplicates = new BugzillaDuplicatesPage(this);
     connectSignals(m_bugzillaDuplicates);
 
-    KPageWidgetItem *m_bugzillaDuplicatesPage = new KPageWidgetItem(m_bugzillaDuplicates, QLatin1String(PAGE_BZDUPLICATES_ID));
+    auto *m_bugzillaDuplicatesPage = new KPageWidgetItem(m_bugzillaDuplicates, QLatin1String(PAGE_BZDUPLICATES_ID));
     m_pageWidgetMap.insert(QLatin1String(PAGE_BZDUPLICATES_ID), m_bugzillaDuplicatesPage);
     m_bugzillaDuplicatesPage->setHeader(i18nc("@title", "Look for Possible Duplicate Reports"));
     m_bugzillaDuplicatesPage->setIcon(QIcon::fromTheme(QStringLiteral("repository")));
 
     //-Bugzilla information
-    BugzillaInformationPage *m_bugzillaInformation = new BugzillaInformationPage(this);
+    auto *m_bugzillaInformation = new BugzillaInformationPage(this);
     connectSignals(m_bugzillaInformation);
 
-    KPageWidgetItem *m_bugzillaInformationPage = new KPageWidgetItem(m_bugzillaInformation, QLatin1String(PAGE_BZDETAILS_ID));
+    auto *m_bugzillaInformationPage = new KPageWidgetItem(m_bugzillaInformation, QLatin1String(PAGE_BZDETAILS_ID));
     m_pageWidgetMap.insert(QLatin1String(PAGE_BZDETAILS_ID), m_bugzillaInformationPage);
     m_bugzillaInformationPage->setHeader(i18nc("@title", "Enter the Details about the Crash"));
     m_bugzillaInformationPage->setIcon(QIcon::fromTheme(QStringLiteral("document-edit")));
 
     //-Bugzilla Report Preview
-    BugzillaPreviewPage *m_bugzillaPreview = new BugzillaPreviewPage(this);
+    auto *m_bugzillaPreview = new BugzillaPreviewPage(this);
 
-    KPageWidgetItem *m_bugzillaPreviewPage = new KPageWidgetItem(m_bugzillaPreview, QLatin1String(PAGE_BZPREVIEW_ID));
+    auto *m_bugzillaPreviewPage = new KPageWidgetItem(m_bugzillaPreview, QLatin1String(PAGE_BZPREVIEW_ID));
     m_pageWidgetMap.insert(QLatin1String(PAGE_BZPREVIEW_ID), m_bugzillaPreviewPage);
     m_bugzillaPreviewPage->setHeader(i18nc("@title", "Preview the Report"));
     m_bugzillaPreviewPage->setIcon(QIcon::fromTheme(QStringLiteral("document-preview")));
 
     //-Bugzilla commit
-    BugzillaSendPage *m_bugzillaSend = new BugzillaSendPage(this);
+    auto *m_bugzillaSend = new BugzillaSendPage(this);
 
-    KPageWidgetItem *m_bugzillaSendPage = new KPageWidgetItem(m_bugzillaSend, QLatin1String(PAGE_BZSEND_ID));
+    auto *m_bugzillaSendPage = new KPageWidgetItem(m_bugzillaSend, QLatin1String(PAGE_BZSEND_ID));
     m_pageWidgetMap.insert(QLatin1String(PAGE_BZSEND_ID), m_bugzillaSendPage);
     m_bugzillaSendPage->setHeader(i18nc("@title", "Sending the Crash Report"));
     m_bugzillaSendPage->setIcon(QIcon::fromTheme(QStringLiteral("applications-internet")));
     connect(m_bugzillaSend, &BugzillaSendPage::finished, this, &ReportAssistantDialog::assistantFinished);
 
-    // TODO Remember to keep the pages ordered
-    addPage(m_awarenessPage);
-    addPage(m_backtracePage);
-    addPage(m_conclusionsPage);
-    addPage(versionPage->item());
-    addPage(m_bugzillaLoginPage);
-    addPage(m_bugzillaDuplicatesPage);
-    addPage(m_bugzillaInformationPage);
-    addPage(m_bugzillaPreviewPage);
-    addPage(m_bugzillaSendPage);
+    // Need to append because the welcome page is conditionally pushed early on.
+    m_pageItems.insert(m_pageItems.end(),
+                       {m_awarenessPage,
+                        m_backtracePage,
+                        m_conclusionsPage,
+                        versionPage->item(),
+                        m_bugzillaLoginPage,
+                        m_bugzillaDuplicatesPage,
+                        m_bugzillaInformationPage,
+                        m_bugzillaPreviewPage,
+                        m_bugzillaSendPage});
+
+    for (const auto pageItem : m_pageItems) {
+        addPage(pageItem);
+    }
 
     // Force a 16:9 ratio for nice appearance by default.
     QSize aspect(16, 9);
@@ -157,9 +162,7 @@ ReportAssistantDialog::ReportAssistantDialog(QWidget *parent)
     resize(aspect);
 }
 
-ReportAssistantDialog::~ReportAssistantDialog()
-{
-}
+ReportAssistantDialog::~ReportAssistantDialog() = default;
 
 void ReportAssistantDialog::setAboutToSend(bool aboutTo)
 {
@@ -190,13 +193,64 @@ void ReportAssistantDialog::currentPageChanged_slot(KPageWidgetItem *current, KP
 
     // Save data of the previous page
     if (before) {
-        ReportAssistantPage *beforePage = qobject_cast<ReportAssistantPage *>(before->widget());
+        auto *beforePage = qobject_cast<ReportAssistantPage *>(before->widget());
         beforePage->aboutToHide();
     }
 
     // Load data of the current(new) page
     if (current) {
-        ReportAssistantPage *currentPage = qobject_cast<ReportAssistantPage *>(current->widget());
+        auto *currentPage = qobject_cast<ReportAssistantPage *>(current->widget());
+
+        if (!currentPage->isAppropriate()) {
+            // The page is inappropriate. Find where to go next. This is extra exhausting because
+            // we can't just find the next or previous appropriate page because next() and back() implement lots of
+            // bespoke movement rules. So we in fact constantly need to go through those functions and then check again here.
+            // WARNING: when no page is appropriate this produces an ininfinite loop. There is no way to
+            //   prevent this right now. next() and back() would need to stop hacking in shortcuts for us to reliably
+            //   determine where to go and when we can't go anywhere.
+            enum class Movement { Unknown, Forward, Backward };
+            auto move = Movement::Unknown;
+            for (auto it = m_pageItems.cbegin(); it != m_pageItems.cend(); ++it) {
+                if (*it == before && move == Movement::Unknown) {
+                    // Found previous item first, we are moving forward ->
+                    move = Movement::Forward;
+                    continue; // continue finding current item, depending on where it is in the container we may need to reverse
+                }
+                if (*it == current) {
+                    if (move == Movement::Unknown) {
+                        // Current item first, we are moving backward <-
+                        move = Movement::Backward;
+                        if (it == m_pageItems.cbegin()) {
+                            // Turn around if this item is first but inappropriate.
+                            move = Movement::Forward;
+                        }
+                    } else if ((it + 1) == m_pageItems.cend()) {
+                        // Turn around if this item is last but inappropriate.
+                        move = Movement::Backward;
+                    }
+                    break;
+                }
+            }
+
+            qCDebug(DRKONQI_LOG) << "page inappropriate, skipping";
+
+            switch (move) {
+            case Movement::Unknown:
+                qCDebug(DRKONQI_LOG) << "unknown";
+                Q_UNREACHABLE();
+                Q_FALLTHROUGH(); // do whatever at this point but do something, the page is inappropriate.
+            case Movement::Forward:
+                qCDebug(DRKONQI_LOG) << "forward";
+                next();
+                return;
+            case Movement::Backward:
+                qCDebug(DRKONQI_LOG) << "backward";
+                back();
+                return;
+            }
+            return;
+        }
+
         nextButton()->setEnabled(currentPage->isComplete());
         currentPage->aboutToShow();
 
@@ -260,7 +314,7 @@ void ReportAssistantDialog::next()
     // just skip over the page).
 
     // Allow the widget to Ask a question to the user before changing the page
-    ReportAssistantPage *page = qobject_cast<ReportAssistantPage *>(currentPage()->widget());
+    auto *page = qobject_cast<ReportAssistantPage *>(currentPage()->widget());
     if (page && !page->showNextPage()) {
         return;
     }
