@@ -1,26 +1,26 @@
 /*******************************************************************
-* reportassistantpages_bugzilla_duplicates.h
-* SPDX-FileCopyrightText: 2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
-* SPDX-FileCopyrightText: 2019 Harald Sitter <sitter@kde.org>
-*
-* SPDX-License-Identifier: GPL-2.0-or-later
-*
-******************************************************************/
+ * reportassistantpages_bugzilla_duplicates.h
+ * SPDX-FileCopyrightText: 2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
+ * SPDX-FileCopyrightText: 2019 Harald Sitter <sitter@kde.org>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
+ ******************************************************************/
 
 #ifndef REPORTASSISTANTPAGES__BUGZILLA__DUPLICATES_H
 #define REPORTASSISTANTPAGES__BUGZILLA__DUPLICATES_H
 
 #include "reportassistantpage.h"
 
-#include "duplicatefinderjob.h"
 #include "bugzillalib.h"
+#include "duplicatefinderjob.h"
 
 #include "ui_assistantpage_bugzilla_duplicates.h"
 #include "ui_assistantpage_bugzilla_duplicates_dialog.h"
 #include "ui_assistantpage_bugzilla_duplicates_dialog_confirmation.h"
+#include <KGuiItem>
 #include <QDate>
 #include <QDialog>
-#include <KGuiItem>
 
 class QDate;
 class QTreeWidgetItem;
@@ -97,7 +97,7 @@ class BugzillaReportInformationDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit BugzillaReportInformationDialog(BugzillaDuplicatesPage*parent=nullptr);
+    explicit BugzillaReportInformationDialog(BugzillaDuplicatesPage *parent = nullptr);
     ~BugzillaReportInformationDialog() override;
 
     void showBugReport(int bugNumber, bool relatedButtonEnabled = true);
@@ -108,8 +108,7 @@ public:
 
 private Q_SLOTS:
     void bugFetchFinished(Bugzilla::Bug::Ptr bug, QObject *);
-    void onCommentsFetched(QList<Bugzilla::Comment::Ptr> bugComments,
-                           QObject *jobOwner);
+    void onCommentsFetched(QList<Bugzilla::Comment::Ptr> bugComments, QObject *jobOwner);
 
     void bugFetchError(QString, QObject *);
 
@@ -124,14 +123,14 @@ Q_SIGNALS:
     void attachToBugReportSelected(int);
 
 private:
-    Ui::AssistantPageBugzillaDuplicatesDialog   ui;
-    bool                                        m_relatedButtonEnabled;
-    BugzillaDuplicatesPage *                    m_parent;
+    Ui::AssistantPageBugzillaDuplicatesDialog ui;
+    bool m_relatedButtonEnabled;
+    BugzillaDuplicatesPage *m_parent;
 
-    int                                         m_bugNumber;
-    QString                                     m_closedStateString;
-    int                                         m_duplicatesCount;
-    QPushButton*                                m_suggestButton;
+    int m_bugNumber;
+    QString m_closedStateString;
+    int m_duplicatesCount;
+    QPushButton *m_suggestButton;
 
     Bugzilla::Bug::Ptr m_bug = nullptr;
 };
@@ -141,8 +140,7 @@ class BugzillaReportConfirmationDialog : public QDialog
     Q_OBJECT
 
 public:
-    BugzillaReportConfirmationDialog(int bugNumber, bool commonCrash, QString closedState,
-                                     BugzillaReportInformationDialog * parent);
+    BugzillaReportConfirmationDialog(int bugNumber, bool commonCrash, QString closedState, BugzillaReportInformationDialog *parent);
     ~BugzillaReportConfirmationDialog() override;
 
 private Q_SLOTS:
@@ -151,12 +149,12 @@ private Q_SLOTS:
     void checkProceed();
 
 private:
-    Ui::ConfirmationDialog              ui;
+    Ui::ConfirmationDialog ui;
 
-    BugzillaReportInformationDialog *   m_parent;
+    BugzillaReportInformationDialog *m_parent;
 
-    bool                                m_showProceedQuestion;
+    bool m_showProceedQuestion;
 
-    int                                 m_bugNumber;
+    int m_bugNumber;
 };
 #endif
