@@ -32,12 +32,14 @@ public:
     static void setAppVersion(const QString &appVersion);
     static void setBugAddress(const QString &bugAddress);
     static void setProgramName(const QString &programName);
+    static void setProductName(const QString &productName);
     static void setPid(int pid);
     static void setKdeinit(bool kdeinit);
     static void setSafer(bool safer);
     static void setRestarted(bool restarted);
     static void setKeepRunning(bool keepRunning);
     static void setThread(int thread);
+    static void setStartupId(const QString &startupId);
 
     static int signal();
     static const QString &appName();
@@ -45,6 +47,7 @@ public:
     static const QString &appVersion();
     static const QString &bugAddress();
     static const QString &programName();
+    static const QString &productName();
     static int pid();
     static bool isKdeinit();
     static bool isSafer();
@@ -53,6 +56,7 @@ public:
     static int thread();
     static bool ignoreQuality();
     static const QString &kdeBugzillaURL();
+    static const QString &startupId();
 
 private:
     DrKonqi();
@@ -68,12 +72,14 @@ private:
     QString m_appVersion;
     QString m_bugAddress;
     QString m_programName;
+    QString m_productName;
     int m_pid;
     bool m_kdeinit;
     bool m_safer;
     bool m_restarted;
     bool m_keepRunning;
     int m_thread;
+    QString m_startupId;
 };
 
 #endif
