@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2009-2010 George Kiagiadakis <kiagiadakis.george@gmail.com>
+    SPDX-FileCopyrightText: 2021 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,10 +8,10 @@
 #define BACKTRACEPARSER_H
 
 #include "backtraceline.h"
-#include <QObject>
-#include <QStringList>
 #include <QMetaType>
+#include <QObject>
 #include <QSet>
+#include <QStringList>
 class BacktraceParserPrivate;
 
 class BacktraceParser : public QObject
@@ -18,10 +19,16 @@ class BacktraceParser : public QObject
     Q_OBJECT
     Q_DECLARE_PRIVATE(BacktraceParser)
 public:
-    enum Usefulness { InvalidUsefulness, Useless, ProbablyUseless, MayBeUseful, ReallyUseful };
+    enum Usefulness {
+        InvalidUsefulness,
+        Useless,
+        ProbablyUseless,
+        MayBeUseful,
+        ReallyUseful,
+    };
     Q_ENUM(Usefulness)
 
-    static BacktraceParser *newParser(const QString & debuggerName, QObject *parent = nullptr);
+    static BacktraceParser *newParser(const QString &debuggerName, QObject *parent = nullptr);
     ~BacktraceParser() override;
 
     /*! Connects the parser to the backtrace generator.
@@ -55,6 +62,11 @@ public:
     /*! Returns a list of libraries/executables that are missing debug symbols. */
     virtual QSet<QString> librariesWithMissingDebugSymbols() const;
 
+    /*! Check if the crash is because of the client aborting after a compositor crash.
+     * https://bugs.kde.org/show_bug.cgi?id=431561
+     */
+    bool hasCompositorCrashed() const;
+
     QString informationLines() const;
 
 private Q_SLOTS:
@@ -66,7 +78,7 @@ protected Q_SLOTS:
      * If the line is useful for rating as well, it should also be inserted in the m_linesToRate
      * field, so that calculateRatingData() can use it.
      */
-    virtual void newLine(const QString & lineStr) = 0;
+    virtual void newLine(const QString &lineStr) = 0;
 
 protected:
     explicit BacktraceParser(QObject *parent = nullptr);
