@@ -6,6 +6,8 @@
 
 #include "statusnotifier.h"
 
+#include <chrono>
+
 #include <QAction>
 #include <QDBusConnectionInterface>
 #include <QDBusServiceWatcher>
@@ -21,6 +23,8 @@
 #include "crashedapplication.h"
 #include "drkonqi.h"
 
+using namespace std::chrono_literals;
+
 StatusNotifier::StatusNotifier(QObject *parent)
     : QObject(parent)
     , m_autoCloseTimer(new QTimer(this))
@@ -50,7 +54,7 @@ void StatusNotifier::show()
 
     // if nobody bothered to look at the crash after 1 minute, just close
     m_autoCloseTimer->setSingleShot(true);
-    m_autoCloseTimer->setInterval(60000);
+    m_autoCloseTimer->setInterval(1min);
     m_autoCloseTimer->start();
     connect(m_autoCloseTimer, &QTimer::timeout, this, &StatusNotifier::expired);
     connect(this, &StatusNotifier::activated, this, &StatusNotifier::deleteLater);
@@ -65,8 +69,8 @@ void StatusNotifier::show()
     // you cannot turn off that "Do you really want to quit?" message, so we'll add our own below
     m_sni->setStandardActionsEnabled(false);
 
-    QMenu *sniMenu = new QMenu();
-    QAction *action = new QAction(QIcon::fromTheme(QStringLiteral("tools-report-bug")), i18n("Report &Bug"), nullptr);
+    auto *sniMenu = new QMenu();
+    auto *action = new QAction(QIcon::fromTheme(QStringLiteral("tools-report-bug")), i18n("Report &Bug"), nullptr);
     connect(action, &QAction::triggered, this, &StatusNotifier::activated);
     sniMenu->addAction(action);
     sniMenu->setDefaultAction(action);
@@ -94,7 +98,7 @@ void StatusNotifier::show()
     // We are tracking the related Notifications service here, because actually
     // tracking the Host interface is fairly involved with no tangible advantage.
     auto activateTimer = new QTimer(this);
-    activateTimer->setInterval(10000);
+    activateTimer->setInterval(10s);
     connect(activateTimer, &QTimer::timeout, this, &StatusNotifier::activated);
 
     auto watcher =
@@ -103,7 +107,7 @@ void StatusNotifier::show()
     connect(watcher, &QDBusServiceWatcher::serviceRegistered, activateTimer, &QTimer::stop);
 
     // make sure the user doesn't miss the SNI by stopping the auto hide timer when the session becomes idle
-    int idleId = KIdleTime::instance()->addIdleTimeout(30000);
+    int idleId = KIdleTime::instance()->addIdleTimeout(int(std::chrono::milliseconds(30s).count()));
     connect(KIdleTime::instance(), static_cast<void (KIdleTime::*)(int, int)>(&KIdleTime::timeoutReached), this, [this, idleId](int id) {
         if (idleId == id) {
             m_autoCloseTimer->stop();
@@ -145,7 +149,7 @@ void StatusNotifier::notify()
 
     connect(notification, static_cast<void (KNotification::*)(unsigned int)>(&KNotification::activated), this, [this, crashedApp](int actionIndex) {
         if (actionIndex == 1 && m_activationAllowed) {
-            emit activated();
+            Q_EMIT activated();
         } else if (canBeRestarted(crashedApp)) {
             crashedApp->restart();
         }
